@@ -33,7 +33,7 @@ from spyder_unittest.widgets.datatree import TestDataModel, TestDataView
 # This is needed for testing this module as a stand alone script
 try:
     _ = get_translation("unittest", dirname="spyder_unittest")
-except KeyError as error:
+except KeyError:
     import gettext
     _ = gettext.gettext
 
@@ -204,7 +204,9 @@ class UnitTestWidget(QWidget):
         """
         if config is None:
             config = self.config
-        return (config and config.framework and osp.isdir(config.wdir))
+        return (config and config.framework
+                and config.framework in self.framework_registry.frameworks
+                and osp.isdir(config.wdir))
 
     def maybe_configure_and_start(self):
         """
@@ -375,7 +377,7 @@ def test():
 
     # set wdir to .../spyder_unittest
     wdir = osp.abspath(osp.join(osp.dirname(__file__), osp.pardir))
-    widget.config = Config('py.test', wdir)
+    widget.config = Config('pytest', wdir)
 
     # add wdir's parent to python path, so that `import spyder_unittest` works
     rootdir = osp.abspath(osp.join(wdir, osp.pardir))
